Files
project_6/cccl_upstream/cudax/test/stf/hashtable/fusion.cu
muh-bot dedf08166a [CCCL] Add missing CCCL components: c2h, nvbench_helper, cmake, cudax, AGENTS.md
Added 863 files from NVIDIA/cccl sparse checkout:
- c2h/ (27 files): Catch2 test helpers — generators, validators, runner
- nvbench_helper/ (10 files): Benchmark harness utilities
- cmake/ (29 files): CMake presets and build helpers
- cudax/ (794 files): Experimental CUDA extensions
- AGENTS.md: NVIDIA's official AI agent instructions for CCCL
- CMakePresets.json: Standardized build configurations
- cccl-version.json: Version tracking

Also added CCCL_ASSET_MAP.md mapping all 4295 CCCL files to
competition value and PRD items.

cccl_upstream now covers 100% of competition-critical assets:
- 27 tuning headers (SM80/90/100 benchmark data)
- 32 dispatch headers (algorithm implementations)
- 60 Thrust examples (correctness verification)
- 217 CUB Catch2 tests (regression matrix)
- 153 CUB benchmarks (parameter space search)
- 18 CUB examples (API verification)
- 27 test helpers + benchmark harness
- 794 cudax experimental extensions
2026-08-06 02:14:18 +00:00

65 lines
1.8 KiB
Plaintext

//===----------------------------------------------------------------------===//
//
// Part of CUDASTF in CUDA C++ Core Libraries,
// under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
//
//===----------------------------------------------------------------------===//
#include <cuda/experimental/__stf/stream/interfaces/hashtable_linearprobing.cuh>
#include <cuda/experimental/__stf/stream/stream_ctx.cuh>
using namespace cuda::experimental::stf;
// Iterate over every item in the hashtableA, and add them to B
__global__ void gpu_merge_hashtable(hashtable A, const hashtable B)
{
unsigned int threadid = blockIdx.x * blockDim.x + threadIdx.x;
while (threadid < reserved::kHashTableCapacity)
{
if (B.addr[threadid].key != reserved::kEmpty)
{
uint32_t value = B.addr[threadid].value;
if (value != reserved::kEmpty)
{
// printf("INSERTING key %d value %d\n", pHashTableB[threadid].key, value);
A.insert(B.addr[threadid]);
}
}
threadid += blockDim.x * gridDim.x;
}
}
int main()
{
stream_ctx ctx;
hashtable A;
A.insert(reserved::KeyValue(107, 4));
A.insert(reserved::KeyValue(108, 6));
hashtable B;
B.insert(reserved::KeyValue(7, 14));
B.insert(reserved::KeyValue(8, 16));
auto lA = ctx.logical_data(A);
auto lB = ctx.logical_data(B);
ctx.task(lA.rw(), lB.read())->*[](auto stream, auto hA, auto hB) {
gpu_merge_hashtable<<<32, 128, 0, stream>>>(hA, hB);
cuda_safe_call(cudaGetLastError());
};
ctx.host_launch(lA.read())->*[](auto hA) {
EXPECT(hA.get(107) == 4);
EXPECT(hA.get(108) == 6);
EXPECT(hA.get(7) == 14);
EXPECT(hA.get(8) == 16);
};
ctx.finalize();
}